==> disposition-0.0.7.tar.gz: disposition-0.0.7/README.md <==
# disposition

[![PyPI - Version](https://img.shields.io/pypi/v/disposition)](https://pypi.org/project/disposition/)
[![Python Versions](https://img.shields.io/pypi/pyversions/disposition)](https://pypi.org/project/disposition/)
[![License](https://img.shields.io/github/license/mortencombat/disposition?color=blue)](https://github.com/mortencombat/disposition/blob/initial-setup/LICENSE)
[![GitHub issues](https://img.shields.io/github/issues/mortencombat/disposition?logo=github)](https://github.com/mortencombat/disposition/issues)
[![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/mortencombat/disposition/create-release.yml?logo=github)](https://github.com/mortencombat/disposition/actions/workflows/create-release.yml)
[![Documentation Status](https://readthedocs.org/projects/disposition/badge/?version=latest)](https://disposition.readthedocs.io/en/latest/?badge=latest)
[![pytest - results](https://gist.github.com/mortencombat/d3bf1bee9867bb5fc725411dc256c185/raw/disposition-tests.svg)](https://github.com/mortencombat/disposition/actions/workflows/run-tests.yml)
[![Test coverage](https://gist.github.com/mortencombat/8ed41c3763b9e12b2f013a0c7d70827c/raw/disposition-coverage.svg)](https://github.com/mortencombat/disposition/actions/workflows/run-tests.yml)

> [!IMPORTANT]
> This framework is in the early stages of planning/development. It is not yet available for use.

**disposition** is a Python-based framework for generating reports and plots with flexible and accurate layouts.

It uses [stretchable](https://github.com/mortencombat/stretchable) (CSS Grid/Flexbox) for layouting and [Matplotlib](https://matplotlib.org/) for rendering.

## License

This work is released under the MIT license. A copy of the license is provided in the [LICENSE](https://github.com/mortencombat/disposition/blob/main/LICENSE) file.

==> disposition-0.1.4.tar.gz: disposition-0.1.4/README.md <==
# disposition

[![PyPI - Version](https://img.shields.io/pypi/v/disposition)](https://pypi.org/project/disposition/)
[![Python Versions](https://img.shields.io/pypi/pyversions/disposition)](https://pypi.org/project/disposition/)
[![License](https://img.shields.io/github/license/mortencombat/disposition?color=blue)](https://github.com/mortencombat/disposition/blob/initial-setup/LICENSE)
[![GitHub issues](https://img.shields.io/github/issues/mortencombat/disposition?logo=github)](https://github.com/mortencombat/disposition/issues)
[![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/mortencombat/disposition/create-release.yml?logo=github)](https://github.com/mortencombat/disposition/actions/workflows/create-release.yml)
[![Documentation Status](https://readthedocs.org/projects/disposition/badge/?version=latest)](https://disposition.readthedocs.io/en/latest/?badge=latest)
[![pytest - results](https://gist.github.com/mortencombat/d3bf1bee9867bb5fc725411dc256c185/raw/disposition-tests.svg)](https://github.com/mortencombat/disposition/actions/workflows/run-tests.yml)
[![Test coverage](https://gist.github.com/mortencombat/8ed41c3763b9e12b2f013a0c7d70827c/raw/disposition-coverage.svg)](https://github.com/mortencombat/disposition/actions/workflows/run-tests.yml)

> [!IMPORTANT]
> This framework is in the early stages of planning/development. It is not yet available for use.

**disposition** is a Python-based framework for generating reports and plots with flexible and precise layouts.

It uses [stretchable](https://github.com/mortencombat/stretchable) (CSS Grid/Flexbox) for layouting and [Matplotlib](https://matplotlib.org/) for rendering.

## License

This work is released under the MIT license. A copy of the license is provided in the [LICENSE](https://github.com/mortencombat/disposition/blob/main/LICENSE) file.
